@@ -1,35 +1,35 @@
 package Blosxom::Plugin::DataSection;
 use strict;
 use warnings;
+use Blosxom::Plugin;
+use Carp qw//;
 use Data::Section::Simple;
 
-my @exports = qw(
-    get_data_section
-    data_section_names
-    merge_data_section_into
+__PACKAGE__->mk_accessors(
+    data_section => sub {
+        my $class = shift;
+        Data::Section::Simple->new($class)->get_data_section;
+    },
 );
 
-sub init {
-    my ( $class, $meta ) = @_;
-    $meta->add_attribute( 'data_section' );
-    $meta->add_method( $_ ) for @exports;
-    return;
-}
+sub get_data_section { $_[0]->data_section->{$_[1]} }
 
-sub _build_data_section {
-    my $class = shift;
-    Data::Section::Simple->new($class)->get_data_section;
-}
-
-sub get_data_section   { shift->data_section->{$_[0]}  }
-sub data_section_names { keys %{ shift->data_section } }
+sub data_section_names { keys %{ $_[0]->data_section } }
 
 sub merge_data_section_into {
-    my ( $class, $merge_into ) = @_;
-    while ( my ($basename, $template) = each %{ $class->data_section } ) {
-        my ( $chunk, $flavour ) = $basename =~ /(.*)\.([^.]*)/;
-        $merge_into->{ $flavour }{ $chunk } = $template;
+    my $class        = shift;
+    my $merge_into   = shift;
+    my $data_section = $class->data_section;
+
+    Carp::croak( 'Not a HASH reference' ) if ref $merge_into ne 'HASH';
+
+    for my $name ( keys %{$data_section} ) {
+        if ( my ($chunk, $flavour) = $name =~ /(.+)\.([^.]+)/ ) {
+            $merge_into->{ $flavour }{ $chunk } = $data_section->{ $name };
+        }
     }
+
+    return;
 }
 
 1;
@@ -38,7 +38,7 @@ __END__
 
 =head1 NAME
 
-Blosxom::Plugin::DataSection - Read data from __DATA__
+Blosxom::Component::DataSection - Read data from __DATA__
 
 =head1 SYNOPSIS
 
